@@ -25,6 +25,7 @@ const (
 	EventUnpack    Event = "unpack"
 	EventInstall   Event = "install"
 	EventUninstall Event = "uninstall"
+	EventExec      Event = "exec" // Triggered when a binary in a package is executed.
 	// Environment specific events
 	EventEnvActivate Event = "activate"
 )
@@ -35,6 +36,7 @@ var eventMap = map[Event]bool{
 	EventInstall:     true,
 	EventUninstall:   true,
 	EventEnvActivate: true,
+	EventExec:        true,
 }
 
 // A Trigger applied when a lifecycle event occurs.
@@ -47,6 +49,8 @@ type Trigger struct {
 	Rename  []*RenameAction  `hcl:"rename,block" help:"Rename a file."`
 	Delete  []*DeleteAction  `hcl:"delete,block" help:"Delete files."`
 	Message []*MessageAction `hcl:"message,block" help:"Display a message to the user."`
+	Mkdir   []*MkdirAction   `hcl:"mkdir,block" help:"Create a directory and any missing parents."`
+	Symlink []*SymlinkAction `hcl:"symlink,block" help:"Create a symbolic link."`
 }
 
 // Ordered list of actions.
@@ -70,6 +74,12 @@ func (a *Trigger) Ordered() []Action {
 	for _, action := range a.Message {
 		out = append(out, action)
 	}
+	for _, action := range a.Mkdir {
+		out = append(out, action)
+	}
+	for _, action := range a.Symlink {
+		out = append(out, action)
+	}
 	sort.Slice(out, func(i, j int) bool {
 		return out[i].position().Line < out[j].position().Line
 	})
